:: commit 8632b112415e552906303dfa74674a41d7318ac3

Mintsuki <mintsuki@protonmail.com> — 2026-04-09 10:41

parents: b5abaf9ac1

protos/limine: Make "Keep IOMMU" feature x86-64-only

diff --git a/bootstrap b/bootstrap
index d8d526ce..051425b1 100755
--- a/bootstrap
+++ b/bootstrap
@@ -85,7 +85,7 @@ if ! test -f version; then
     clone_repo_commit \
         https://github.com/Limine-Bootloader/limine-protocol.git \
         limine-protocol \
-        72502bba1777afa4723894f04ae88fe9d41ecc3c
+        6f3fafe337c30f94e7c2f5c4a21498346c5604bf
 
     clone_repo_commit \
         https://github.com/PicoEFI/PicoEFI.git \
diff --git a/common/protos/limine.c b/common/protos/limine.c
index 92be6189..23349b87 100644
--- a/common/protos/limine.c
+++ b/common/protos/limine.c
@@ -945,18 +945,18 @@ FEAT_START
     entrypoint_request->response = reported_addr(entrypoint_response);
 FEAT_END
 
     // Keep IOMMU feature
 #if defined (__x86_64__) || defined (__i386__)
     bool keep_iommu = false;
 FEAT_START
-    struct limine_keep_iommu_request *keep_iommu_request =
-        get_request(LIMINE_KEEP_IOMMU_REQUEST_ID);
+    struct limine_x86_64_keep_iommu_request *keep_iommu_request =
+        get_request(LIMINE_X86_64_KEEP_IOMMU_REQUEST_ID);
     if (keep_iommu_request == NULL) {
         break;
     }
 
-    struct limine_keep_iommu_response *keep_iommu_response =
-        ext_mem_alloc(sizeof(struct limine_keep_iommu_response));
+    struct limine_x86_64_keep_iommu_response *keep_iommu_response =
+        ext_mem_alloc(sizeof(struct limine_x86_64_keep_iommu_response));
 
     keep_iommu_request->response = reported_addr(keep_iommu_response);
     keep_iommu = true;
@@ -945,18 +945,18 @@ FEAT_START
 FEAT_END
 
-    // Keep IOMMU feature
+    // x86-64 Keep IOMMU feature
 #if defined (__x86_64__) || defined (__i386__)
     bool keep_iommu = false;
tab: 248 wrap: offon